# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

"""
This module contains miscellaneous utility methods that don't really fit anywhere else.
"""

from __future__ import annotations

from typing import Generator, Iterable, TypeVar

T = TypeVar("T")
K = TypeVar("K")
V = TypeVar("V")


__all__ = ["boundary_iter", "flatten"]


def boundary_iter(obj: Iterable[T], /) -> Generator[tuple[bool, T], None, None]:
    """
    Iterates over an iterable, returning a boolean and the underlying values indicating
    whether the iterator has reached its last item.

    >>> list(boundary_iter(range(0, 3)))
    [(False, 0), (False, 1), (True, 2)]

    >>> list(boundary_iter('A'))
    [(True, 'A')]

    # empty example
    >>> list(boundary_iter([]))
    []

    # iterating over an infinite iterable
    >>> import itertools
    >>> list(itertools.islice(boundary_iter(iter(lambda:0,1)), 4))
    [(False, 0), (False, 0), (False, 0), (False, 0)]
    """
    gen = iter(obj)
    prev_entry = None
    while True:
        try:
            entry = next(gen)
            if prev_entry is not None:
                yield False, prev_entry
            prev_entry = entry
        except StopIteration:
            if prev_entry is not None:
                yield True, prev_entry
            break


def flatten(obj: Iterable[Iterable[T]], /) -> list[T]:
    ret = list[T]()
    for sublist in obj:
        ret.extend(sublist)
    return ret



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

import logging
from pathlib import Path
import shutil
import subprocess
import sys

from .codegen.python_header import HEADER

logger = logging.getLogger("_dazl.generate_api")

__all__ = ["generate_api_clients"]


def _add_copyright_headers(directory: Path) -> None:
    for py_file in directory.rglob("*.py"):
        content = py_file.read_text()
        if not content.startswith("# Copyright"):
            py_file.write_text(HEADER + content)
            logger.debug(f"Added copyright header to {py_file}")


def _fix_missing_response_models(directory: Path) -> None:
    openapi_dir = directory / "openapi"
    models_dir = openapi_dir / "models"
    api_dir = openapi_dir / "api" / "default"

    response_file = models_dir / "list_vetted_packages_response.py"
    response_content = (
        HEADER
        + '''from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

if TYPE_CHECKING:
    from ..models.vetted_package import VettedPackage


T = TypeVar("T", bound="ListVettedPackagesResponse")


@_attrs_define
class ListVettedPackagesResponse:
    """
    Attributes:
        next_page_token (str): Pagination token to fetch the next page.
        vetted_packages (list[VettedPackage]): List of vetted packages.
    """

    next_page_token: str
    vetted_packages: list[VettedPackage]
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        next_page_token = self.next_page_token

        vetted_packages = []
        for vetted_packages_item_data in self.vetted_packages:
            vetted_packages_item = vetted_packages_item_data.to_dict()
            vetted_packages.append(vetted_packages_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "nextPageToken": next_page_token,
                "vettedPackages": vetted_packages,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.vetted_package import VettedPackage

        d = dict(src_dict)
        next_page_token = d.pop("nextPageToken", "")

        vetted_packages = []
        _vetted_packages = d.pop("vettedPackages", [])
        for vetted_packages_item_data in _vetted_packages:
            vetted_packages_item = VettedPackage.from_dict(vetted_packages_item_data)
            vetted_packages.append(vetted_packages_item)

        list_vetted_packages_response = cls(
            next_page_token=next_page_token,
            vetted_packages=vetted_packages,
        )

        list_vetted_packages_response.additional_properties = d
        return list_vetted_packages_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
'''
    )
    response_file.write_text(response_content)
    logger.debug(f"Created {response_file}")

    api_file = api_dir / "get_v2_package_vetting.py"
    if api_file.exists():
        content = api_file.read_text()

        content = content.replace(
            "from ...models.list_vetted_packages_request import ListVettedPackagesRequest\nfrom ...types import Response",
            "from ...models.list_vetted_packages_request import ListVettedPackagesRequest\nfrom ...models.list_vetted_packages_response import ListVettedPackagesResponse\nfrom ...types import Response",
        )

        content = content.replace(
            "def _parse_response(\n    *, client: AuthenticatedClient | Client, response: httpx.Response\n) -> JsCantonError | str:\n    if response.status_code == 400:\n        response_400 = response.text\n        return response_400\n\n    response_default = JsCantonError.from_dict(response.json())\n\n    return response_default",
            "def _parse_response(\n    *, client: AuthenticatedClient | Client, response: httpx.Response\n) -> ListVettedPackagesResponse | JsCantonError | str:\n    if response.status_code == 200:\n        response_200 = ListVettedPackagesResponse.from_dict(response.json())\n        return response_200\n\n    if response.status_code == 400:\n        response_400 = response.text\n        return response_400\n\n    response_default = JsCantonError.from_dict(response.json())\n\n    return response_default",
        )

        content = content.replace(
            "Response[JsCantonError | str]",
            "Response[ListVettedPackagesResponse | JsCantonError | str]",
        )

        content = content.replace(
            ") -> JsCantonError | str | None:",
            ") -> ListVettedPackagesResponse | JsCantonError | str | None:",
        )

        content = content.replace(
            "    Returns:\n        JsCantonError | str",
            "    Returns:\n        ListVettedPackagesResponse | JsCantonError | str",
        )

        api_file.write_text(content)
        logger.debug(f"Fixed {api_file}")

    init_file = models_dir / "__init__.py"
    if init_file.exists():
        content = init_file.read_text()

        content = content.replace(
            "from .list_vetted_packages_request import ListVettedPackagesRequest\nfrom .map_int_field import MapIntField",
            "from .list_vetted_packages_request import ListVettedPackagesRequest\nfrom .list_vetted_packages_response import ListVettedPackagesResponse\nfrom .map_int_field import MapIntField",
        )

        content = content.replace(
            '    "ListVettedPackagesRequest",\n    "MapIntField",',
            '    "ListVettedPackagesRequest",\n    "ListVettedPackagesResponse",\n    "MapIntField",',
        )

        init_file.write_text(content)
        logger.debug(f"Updated {init_file}")


def _fix_post_packages_multipart(directory: Path) -> None:
    openapi_dir = directory / "openapi"
    api_dir = openapi_dir / "api" / "default"
    api_file = api_dir / "post_v2_packages.py"

    if not api_file.exists():
        logger.warning(f"File {api_file} not found, skipping multipart fix")
        return

    content = api_file.read_text()

    old_get_kwargs = '''    _kwargs["content"] = body.payload

    headers["Content-Type"] = "application/octet-stream"'''

    new_get_kwargs = """    _kwargs["files"] = {"darFile": (body.file_name or "package.dar", body.payload, body.mime_type or "application/octet-stream")}"""

    if old_get_kwargs in content:
        content = content.replace(old_get_kwargs, new_get_kwargs)
        api_file.write_text(content)
        logger.debug(f"Fixed {api_file} to use multipart/form-data")
    else:
        logger.warning(f"Could not find expected content in {api_file}, multipart fix not applied")


def _format_generated_code(directory: Path) -> None:
    venv_bin = Path(sys.executable).parent
    isort_exe = venv_bin / "isort"
    black_exe = venv_bin / "black"

    try:
        subprocess.run(
            [str(isort_exe), str(directory)],
            check=True,
            capture_output=True,
            text=True,
        )
        logger.debug("Successfully ran isort")
    except subprocess.CalledProcessError as e:
        logger.warning(f"isort failed: {e.stderr}")

    try:
        subprocess.run(
            [str(black_exe), str(directory)],
            check=True,
            capture_output=True,
            text=True,
        )
        logger.debug("Successfully ran black")
    except subprocess.CalledProcessError as e:
        logger.warning(f"black failed: {e.stderr}")


def generate_api_clients(openapi_specs_dir: Path, output_dir: Path) -> None:
    if output_dir.exists():
        shutil.rmtree(output_dir)
    output_dir.mkdir(parents=True, exist_ok=True)

    spec_file = openapi_specs_dir / "ledger-api" / "openapi.yaml"
    if not spec_file.exists():
        logger.error(f"Ledger API spec not found at {spec_file}")
        return

    logger.info(f"Generating Ledger API client from {spec_file}")

    venv_bin = Path(sys.executable).parent
    openapi_client_exe = venv_bin / "openapi-python-client"

    if not openapi_client_exe.exists():
        logger.error(f"openapi-python-client not found at {openapi_client_exe}")
        return

    client_output_dir = output_dir / "openapi"

    try:
        subprocess.run(
            [
                str(openapi_client_exe),
                "generate",
                "--path",
                str(spec_file),
                "--output-path",
                str(client_output_dir),
                "--meta",
                "none",
            ],
            check=True,
            capture_output=True,
            text=True,
        )
        logger.info("Successfully generated Ledger API client")

        _add_copyright_headers(client_output_dir)
        logger.info("Added copyright headers to generated files")

        _fix_missing_response_models(output_dir)
        logger.info("Fixed missing response models")

        _fix_post_packages_multipart(output_dir)
        logger.info("Fixed POST /v2/packages to use multipart/form-data")

        _format_generated_code(output_dir)
        logger.info("Formatted generated files")
    except subprocess.CalledProcessError as e:
        logger.error(f"Failed to generate client: {e.stderr}")
        return

    init_file = output_dir / "__init__.py"
    init_file.write_text(
        "# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.\n"
        "# SPDX-License-Identifier: Apache-2.0\n"
        "\n"
        "from __future__ import annotations\n"
        "\n"
        "from .openapi.client import AuthenticatedClient, Client\n"
        "\n"
        '__all__ = ["Client", "AuthenticatedClient"]\n'
    )



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/time/admin/v30/synchronizer_time_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/time/admin/v30/synchronizer_time_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....topology.admin.v30 import common_pb2 as com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_common__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFcom/digitalasset/canton/time/admin/v30/synchronizer_time_service.proto\x12&com.digitalasset.canton.time.admin.v30\x1a\x37\x63om/digitalasset/canton/topology/admin/v30/common.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xca\x01\n\x10\x46\x65tchTimeRequest\x12\x61\n\x0csynchronizer\x18\x01 \x01(\x0b\x32\x38.com.digitalasset.canton.topology.admin.v30.SynchronizerH\x00R\x0csynchronizer\x88\x01\x01\x12\x42\n\x0f\x66reshness_bound\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0e\x66reshnessBoundB\x0f\n\r_synchronizer\"M\n\x11\x46\x65tchTimeResponse\x12\x38\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\"\xc0\x01\n\x10\x41waitTimeRequest\x12\x61\n\x0csynchronizer\x18\x01 \x01(\x0b\x32\x38.com.digitalasset.canton.topology.admin.v30.SynchronizerH\x00R\x0csynchronizer\x88\x01\x01\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestampB\x0f\n\r_synchronizer\"\x13\n\x11\x41waitTimeResponse2\x9f\x02\n\x17SynchronizerTimeService\x12\x80\x01\n\tFetchTime\x12\x38.com.digitalasset.canton.time.admin.v30.FetchTimeRequest\x1a\x39.com.digitalasset.canton.time.admin.v30.FetchTimeResponse\x12\x80\x01\n\tAwaitTime\x12\x38.com.digitalasset.canton.time.admin.v30.AwaitTimeRequest\x1a\x39.com.digitalasset.canton.time.admin.v30.AwaitTimeResponseBWZUgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/time/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.time.admin.v30.synchronizer_time_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZUgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/time/admin/v30'
  _globals['_FETCHTIMEREQUEST']._serialized_start=237
  _globals['_FETCHTIMEREQUEST']._serialized_end=439
  _globals['_FETCHTIMERESPONSE']._serialized_start=441
  _globals['_FETCHTIMERESPONSE']._serialized_end=518
  _globals['_AWAITTIMEREQUEST']._serialized_start=521
  _globals['_AWAITTIMEREQUEST']._serialized_end=713
  _globals['_AWAITTIMERESPONSE']._serialized_start=715
  _globals['_AWAITTIMERESPONSE']._serialized_end=734
  _globals['_SYNCHRONIZERTIMESERVICE']._serialized_start=737
  _globals['_SYNCHRONIZERTIMESERVICE']._serialized_end=1024
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
import datetime

from . import experimental_features_pb2 as _experimental_features_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetLedgerApiVersionRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetLedgerApiVersionResponse(_message.Message):
    __slots__ = ("version", "features")
    VERSION_FIELD_NUMBER: _ClassVar[int]
    FEATURES_FIELD_NUMBER: _ClassVar[int]
    version: str
    features: FeaturesDescriptor
    def __init__(self, version: _Optional[str] = ..., features: _Optional[_Union[FeaturesDescriptor, _Mapping]] = ...) -> None: ...

class FeaturesDescriptor(_message.Message):
    __slots__ = ("experimental", "user_management", "party_management", "offset_checkpoint", "package_feature")
    EXPERIMENTAL_FIELD_NUMBER: _ClassVar[int]
    USER_MANAGEMENT_FIELD_NUMBER: _ClassVar[int]
    PARTY_MANAGEMENT_FIELD_NUMBER: _ClassVar[int]
    OFFSET_CHECKPOINT_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_FEATURE_FIELD_NUMBER: _ClassVar[int]
    experimental: _experimental_features_pb2.ExperimentalFeatures
    user_management: UserManagementFeature
    party_management: PartyManagementFeature
    offset_checkpoint: OffsetCheckpointFeature
    package_feature: PackageFeature
    def __init__(self, experimental: _Optional[_Union[_experimental_features_pb2.ExperimentalFeatures, _Mapping]] = ..., user_management: _Optional[_Union[UserManagementFeature, _Mapping]] = ..., party_management: _Optional[_Union[PartyManagementFeature, _Mapping]] = ..., offset_checkpoint: _Optional[_Union[OffsetCheckpointFeature, _Mapping]] = ..., package_feature: _Optional[_Union[PackageFeature, _Mapping]] = ...) -> None: ...

class UserManagementFeature(_message.Message):
    __slots__ = ("supported", "max_rights_per_user", "max_users_page_size")
    SUPPORTED_FIELD_NUMBER: _ClassVar[int]
    MAX_RIGHTS_PER_USER_FIELD_NUMBER: _ClassVar[int]
    MAX_USERS_PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    supported: bool
    max_rights_per_user: int
    max_users_page_size: int
    def __init__(self, supported: bool = ..., max_rights_per_user: _Optional[int] = ..., max_users_page_size: _Optional[int] = ...) -> None: ...

class PartyManagementFeature(_message.Message):
    __slots__ = ("max_parties_page_size",)
    MAX_PARTIES_PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    max_parties_page_size: int
    def __init__(self, max_parties_page_size: _Optional[int] = ...) -> None: ...

class PackageFeature(_message.Message):
    __slots__ = ("max_vetted_packages_page_size",)
    MAX_VETTED_PACKAGES_PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    max_vetted_packages_page_size: int
    def __init__(self, max_vetted_packages_page_size: _Optional[int] = ...) -> None: ...

class OffsetCheckpointFeature(_message.Message):
    __slots__ = ("max_offset_checkpoint_emission_delay",)
    MAX_OFFSET_CHECKPOINT_EMISSION_DELAY_FIELD_NUMBER: _ClassVar[int]
    max_offset_checkpoint_emission_delay: _duration_pb2.Duration
    def __init__(self, max_offset_checkpoint_emission_delay: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from enum import Enum


class GetPackageStatusResponsePackageStatus(str, Enum):
    PACKAGE_STATUS_REGISTERED = "PACKAGE_STATUS_REGISTERED"
    PACKAGE_STATUS_UNSPECIFIED = "PACKAGE_STATUS_UNSPECIFIED"

    def __str__(self) -> str:
        return str(self.value)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .party_name_management_pb2 import SetPartyDisplayNameRequest, SetPartyDisplayNameResponse

__all__ = [
    "PartyNameManagementServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class PartyNameManagementServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _PartyNameManagementServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _PartyNameManagementServiceAsyncStub: ...  # type: ignore
    def setPartyDisplayName(self, __1: SetPartyDisplayNameRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SetPartyDisplayNameResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, SetPartyDisplayNameResponse]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _PartyNameManagementServiceBlockingStub(PartyNameManagementServiceStub):
    def setPartyDisplayName(self, __1: SetPartyDisplayNameRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SetPartyDisplayNameResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _PartyNameManagementServiceAsyncStub(PartyNameManagementServiceStub):
    def setPartyDisplayName(self, __1: SetPartyDisplayNameRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SetPartyDisplayNameResponse]: ...  # type: ignore



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
import datetime

from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AcsCommitment(_message.Message):
    __slots__ = ("domain_id", "sending_participant", "counter_participant", "from_exclusive", "to_inclusive", "commitment")
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    SENDING_PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    COUNTER_PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    FROM_EXCLUSIVE_FIELD_NUMBER: _ClassVar[int]
    TO_INCLUSIVE_FIELD_NUMBER: _ClassVar[int]
    COMMITMENT_FIELD_NUMBER: _ClassVar[int]
    domain_id: str
    sending_participant: str
    counter_participant: str
    from_exclusive: _timestamp_pb2.Timestamp
    to_inclusive: _timestamp_pb2.Timestamp
    commitment: bytes
    def __init__(self, domain_id: _Optional[str] = ..., sending_participant: _Optional[str] = ..., counter_participant: _Optional[str] = ..., from_exclusive: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., to_inclusive: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., commitment: _Optional[bytes] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/crypto.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/daml/ledger/api/v2/crypto.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#com/daml/ledger/api/v2/crypto.proto\x12\x16\x63om.daml.ledger.api.v2\"\xb1\x01\n\x10SigningPublicKey\x12?\n\x06\x66ormat\x18\x01 \x01(\x0e\x32\'.com.daml.ledger.api.v2.CryptoKeyFormatR\x06\x66ormat\x12\x19\n\x08key_data\x18\x02 \x01(\x0cR\x07keyData\x12\x41\n\x08key_spec\x18\x03 \x01(\x0e\x32&.com.daml.ledger.api.v2.SigningKeySpecR\x07keySpec\"\xeb\x01\n\tSignature\x12?\n\x06\x66ormat\x18\x01 \x01(\x0e\x32\'.com.daml.ledger.api.v2.SignatureFormatR\x06\x66ormat\x12\x1c\n\tsignature\x18\x02 \x01(\x0cR\tsignature\x12\x1b\n\tsigned_by\x18\x03 \x01(\tR\x08signedBy\x12\x62\n\x16signing_algorithm_spec\x18\x04 \x01(\x0e\x32,.com.daml.ledger.api.v2.SigningAlgorithmSpecR\x14signingAlgorithmSpec*\xb5\x01\n\x0eSigningKeySpec\x12 \n\x1cSIGNING_KEY_SPEC_UNSPECIFIED\x10\x00\x12\"\n\x1eSIGNING_KEY_SPEC_EC_CURVE25519\x10\x01\x12\x1c\n\x18SIGNING_KEY_SPEC_EC_P256\x10\x02\x12\x1c\n\x18SIGNING_KEY_SPEC_EC_P384\x10\x03\x12!\n\x1dSIGNING_KEY_SPEC_EC_SECP256K1\x10\x04*\xaa\x01\n\x0f\x43ryptoKeyFormat\x12!\n\x1d\x43RYPTO_KEY_FORMAT_UNSPECIFIED\x10\x00\x12\x19\n\x15\x43RYPTO_KEY_FORMAT_DER\x10\x01\x12\x19\n\x15\x43RYPTO_KEY_FORMAT_RAW\x10\x02\x12\x36\n2CRYPTO_KEY_FORMAT_DER_X509_SUBJECT_PUBLIC_KEY_INFO\x10\x03\"\x06\x08\x90N\x10\x90N*\xb8\x01\n\x14SigningAlgorithmSpec\x12&\n\"SIGNING_ALGORITHM_SPEC_UNSPECIFIED\x10\x00\x12\"\n\x1eSIGNING_ALGORITHM_SPEC_ED25519\x10\x01\x12)\n%SIGNING_ALGORITHM_SPEC_EC_DSA_SHA_256\x10\x02\x12)\n%SIGNING_ALGORITHM_SPEC_EC_DSA_SHA_384\x10\x03*\xa4\x01\n\x0fSignatureFormat\x12 \n\x1cSIGNATURE_FORMAT_UNSPECIFIED\x10\x00\x12\x18\n\x14SIGNATURE_FORMAT_RAW\x10\x01\x12\x18\n\x14SIGNATURE_FORMAT_DER\x10\x02\x12\x1b\n\x17SIGNATURE_FORMAT_CONCAT\x10\x03\x12\x1e\n\x19SIGNATURE_FORMAT_SYMBOLIC\x10\x90NB\x8a\x01\n\x16\x63om.daml.ledger.api.v2B\x10\x43ryptoOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\xaa\x02\x16\x43om.Daml.Ledger.Api.V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.crypto_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.daml.ledger.api.v2B\020CryptoOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\252\002\026Com.Daml.Ledger.Api.V2'
  _globals['_SIGNINGKEYSPEC']._serialized_start=482
  _globals['_SIGNINGKEYSPEC']._serialized_end=663
  _globals['_CRYPTOKEYFORMAT']._serialized_start=666
  _globals['_CRYPTOKEYFORMAT']._serialized_end=836
  _globals['_SIGNINGALGORITHMSPEC']._serialized_start=839
  _globals['_SIGNINGALGORITHMSPEC']._serialized_end=1023
  _globals['_SIGNATUREFORMAT']._serialized_start=1026
  _globals['_SIGNATUREFORMAT']._serialized_end=1190
  _globals['_SIGNINGPUBLICKEY']._serialized_start=64
  _globals['_SIGNINGPUBLICKEY']._serialized_end=241
  _globals['_SIGNATURE']._serialized_start=244
  _globals['_SIGNATURE']._serialized_end=479
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v0/topology_ext.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/protocol/v0/topology_ext.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6com/digitalasset/canton/protocol/v0/topology_ext.proto\x12#com.digitalasset.canton.protocol.v0\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc9\x02\n\x14TopologyTransactions\x12T\n\x05items\x18\x01 \x03(\x0b\x32>.com.digitalasset.canton.protocol.v0.TopologyTransactions.ItemR\x05items\x1a\xda\x01\n\x04Item\x12\x38\n\tsequenced\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tsequenced\x12\x39\n\nvalid_from\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tvalidFrom\x12;\n\x0bvalid_until\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nvalidUntil\x12 \n\x0btransaction\x18\x03 \x01(\x0cR\x0btransactionBTZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v0.topology_ext_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v0'
  _globals['_TOPOLOGYTRANSACTIONS']._serialized_start=129
  _globals['_TOPOLOGYTRANSACTIONS']._serialized_end=458
  _globals['_TOPOLOGYTRANSACTIONS_ITEM']._serialized_start=240
  _globals['_TOPOLOGYTRANSACTIONS_ITEM']._serialized_end=458
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
import datetime

from ....admin.pruning.v30 import pruning_pb2 as _pruning_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BftPruneRequest(_message.Message):
    __slots__ = ("retention", "min_blocks_to_keep")
    RETENTION_FIELD_NUMBER: _ClassVar[int]
    MIN_BLOCKS_TO_KEEP_FIELD_NUMBER: _ClassVar[int]
    retention: _duration_pb2.Duration
    min_blocks_to_keep: int
    def __init__(self, retention: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., min_blocks_to_keep: _Optional[int] = ...) -> None: ...

class BftPruneResponse(_message.Message):
    __slots__ = ("message",)
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    message: str
    def __init__(self, message: _Optional[str] = ...) -> None: ...

class BftPruningStatusRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class BftPruningStatusResponse(_message.Message):
    __slots__ = ("latest_block_epoch", "latest_block", "latest_block_timestamp", "lower_bound_epoch", "lower_bound_block")
    LATEST_BLOCK_EPOCH_FIELD_NUMBER: _ClassVar[int]
    LATEST_BLOCK_FIELD_NUMBER: _ClassVar[int]
    LATEST_BLOCK_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    LOWER_BOUND_EPOCH_FIELD_NUMBER: _ClassVar[int]
    LOWER_BOUND_BLOCK_FIELD_NUMBER: _ClassVar[int]
    latest_block_epoch: int
    latest_block: int
    latest_block_timestamp: _timestamp_pb2.Timestamp
    lower_bound_epoch: int
    lower_bound_block: int
    def __init__(self, latest_block_epoch: _Optional[int] = ..., latest_block: _Optional[int] = ..., latest_block_timestamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., lower_bound_epoch: _Optional[int] = ..., lower_bound_block: _Optional[int] = ...) -> None: ...

class SetBftScheduleRequest(_message.Message):
    __slots__ = ("schedule",)
    SCHEDULE_FIELD_NUMBER: _ClassVar[int]
    schedule: BftOrdererPruningSchedule
    def __init__(self, schedule: _Optional[_Union[BftOrdererPruningSchedule, _Mapping]] = ...) -> None: ...

class BftOrdererPruningSchedule(_message.Message):
    __slots__ = ("schedule", "min_blocks_to_keep")
    SCHEDULE_FIELD_NUMBER: _ClassVar[int]
    MIN_BLOCKS_TO_KEEP_FIELD_NUMBER: _ClassVar[int]
    schedule: _pruning_pb2.PruningSchedule
    min_blocks_to_keep: int
    def __init__(self, schedule: _Optional[_Union[_pruning_pb2.PruningSchedule, _Mapping]] = ..., min_blocks_to_keep: _Optional[int] = ...) -> None: ...

class SetBftScheduleResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetBftScheduleRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetBftScheduleResponse(_message.Message):
    __slots__ = ("schedule",)
    SCHEDULE_FIELD_NUMBER: _ClassVar[int]
    schedule: BftOrdererPruningSchedule
    def __init__(self, schedule: _Optional[_Union[BftOrdererPruningSchedule, _Mapping]] = ...) -> None: ...

class SetMinBlocksToKeepRequest(_message.Message):
    __slots__ = ("min_blocks_to_keep",)
    MIN_BLOCKS_TO_KEEP_FIELD_NUMBER: _ClassVar[int]
    min_blocks_to_keep: int
    def __init__(self, min_blocks_to_keep: _Optional[int] = ...) -> None: ...

class SetMinBlocksToKeepResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .synchronizer_time_service_pb2 import AwaitTimeRequest, AwaitTimeResponse, FetchTimeRequest, FetchTimeResponse
from .synchronizer_time_service_pb2_grpc import SynchronizerTimeServiceStub

__all__ = [
    "AwaitTimeRequest",
    "AwaitTimeResponse",
    "FetchTimeRequest",
    "FetchTimeResponse",
    "SynchronizerTimeServiceStub",
]



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .topology_manager_read_service_pb2 import ListAllRequest, ListAllResponse, ListAvailableStoresRequest, ListAvailableStoresResult, ListCheckOnlyPackagesRequest, ListCheckOnlyPackagesResult, ListDomainParametersChangesRequest, ListDomainParametersChangesResult, ListIdentifierDelegationRequest, ListIdentifierDelegationResult, ListMediatorDomainStateRequest, ListMediatorDomainStateResult, ListNamespaceDelegationRequest, ListNamespaceDelegationResult, ListOwnerToKeyMappingRequest, ListOwnerToKeyMappingResult, ListParticipantDomainStateRequest, ListParticipantDomainStateResult, ListPartyToParticipantRequest, ListPartyToParticipantResult, ListSignedLegalIdentityClaimRequest, ListSignedLegalIdentityClaimResult, ListVettedPackagesRequest, ListVettedPackagesResult

__all__ = [
    "TopologyManagerReadServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class TopologyManagerReadServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _TopologyManagerReadServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _TopologyManagerReadServiceAsyncStub: ...  # type: ignore
    def ListAvailableStores(self, __1: ListAvailableStoresRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListAvailableStoresResult | _grpc_aio.UnaryUnaryCall[_typing.Any, ListAvailableStoresResult]: ...
    def ListPartyToParticipant(self, __1: ListPartyToParticipantRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListPartyToParticipantResult | _grpc_aio.UnaryUnaryCall[_typing.Any, ListPartyToParticipantResult]: ...
    def ListOwnerToKeyMapping(self, __1: ListOwnerToKeyMappingRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListOwnerToKeyMappingResult | _grpc_aio.UnaryUnaryCall[_typing.Any, ListOwnerToKeyMappingResult]: ...
    def ListNamespaceDelegation(self, __1: ListNamespaceDelegationRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListNamespaceDelegationResult | _grpc_aio.UnaryUnaryCall[_typing.Any, ListNamespaceDelegationResult]: ...
    def ListIdentifierDelegation(self, __1: ListIdentifierDelegationRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListIdentifierDelegationResult | _grpc_aio.UnaryUnaryCall[_typing.Any, ListIdentifierDelegationResult]: ...
    def ListSignedLegalIdentityClaim(self, __1: ListSignedLegalIdentityClaimRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListSignedLegalIdentityClaimResult | _grpc_aio.UnaryUnaryCall[_typing.Any, ListSignedLegalIdentityClaimResult]: ...
    def ListParticipantDomainState(self, __1: ListParticipantDomainStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListParticipantDomainStateResult | _grpc_aio.UnaryUnaryCall[_typing.Any, ListParticipantDomainStateResult]: ...
    def ListMediatorDomainState(self, __1: ListMediatorDomainStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListMediatorDomainStateResult | _grpc_aio.UnaryUnaryCall[_typing.Any, ListMediatorDomainStateResult]: ...
    def ListVettedPackages(self, __1: ListVettedPackagesRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListVettedPackagesResult | _grpc_aio.UnaryUnaryCall[_typing.Any, ListVettedPackagesResult]: ...
    def ListCheckOnlyPackages(self, __1: ListCheckOnlyPackagesRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListCheckOnlyPackagesResult | _grpc_aio.UnaryUnaryCall[_typing.Any, ListCheckOnlyPackagesResult]: ...
    def ListDomainParametersChanges(self, __1: ListDomainParametersChangesRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListDomainParametersChangesResult | _grpc_aio.UnaryUnaryCall[_typing.Any, ListDomainParametersChangesResult]: ...
    def ListAll(self, __1: ListAllRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListAllResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListAllResponse]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _TopologyManagerReadServiceBlockingStub(TopologyManagerReadServiceStub):
    def ListAvailableStores(self, __1: ListAvailableStoresRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListAvailableStoresResult: ...
    def ListPartyToParticipant(self, __1: ListPartyToParticipantRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListPartyToParticipantResult: ...
    def ListOwnerToKeyMapping(self, __1: ListOwnerToKeyMappingRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListOwnerToKeyMappingResult: ...
    def ListNamespaceDelegation(self, __1: ListNamespaceDelegationRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListNamespaceDelegationResult: ...
    def ListIdentifierDelegation(self, __1: ListIdentifierDelegationRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListIdentifierDelegationResult: ...
    def ListSignedLegalIdentityClaim(self, __1: ListSignedLegalIdentityClaimRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListSignedLegalIdentityClaimResult: ...
    def ListParticipantDomainState(self, __1: ListParticipantDomainStateRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListParticipantDomainStateResult: ...
    def ListMediatorDomainState(self, __1: ListMediatorDomainStateRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListMediatorDomainStateResult: ...
    def ListVettedPackages(self, __1: ListVettedPackagesRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListVettedPackagesResult: ...
    def ListCheckOnlyPackages(self, __1: ListCheckOnlyPackagesRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListCheckOnlyPackagesResult: ...
    def ListDomainParametersChanges(self, __1: ListDomainParametersChangesRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListDomainParametersChangesResult: ...
    def ListAll(self, __1: ListAllRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListAllResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _TopologyManagerReadServiceAsyncStub(TopologyManagerReadServiceStub):
    def ListAvailableStores(self, __1: ListAvailableStoresRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListAvailableStoresResult]: ...  # type: ignore
    def ListPartyToParticipant(self, __1: ListPartyToParticipantRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListPartyToParticipantResult]: ...  # type: ignore
    def ListOwnerToKeyMapping(self, __1: ListOwnerToKeyMappingRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListOwnerToKeyMappingResult]: ...  # type: ignore
    def ListNamespaceDelegation(self, __1: ListNamespaceDelegationRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListNamespaceDelegationResult]: ...  # type: ignore
    def ListIdentifierDelegation(self, __1: ListIdentifierDelegationRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListIdentifierDelegationResult]: ...  # type: ignore
    def ListSignedLegalIdentityClaim(self, __1: ListSignedLegalIdentityClaimRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListSignedLegalIdentityClaimResult]: ...  # type: ignore
    def ListParticipantDomainState(self, __1: ListParticipantDomainStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListParticipantDomainStateResult]: ...  # type: ignore
    def ListMediatorDomainState(self, __1: ListMediatorDomainStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListMediatorDomainStateResult]: ...  # type: ignore
    def ListVettedPackages(self, __1: ListVettedPackagesRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListVettedPackagesResult]: ...  # type: ignore
    def ListCheckOnlyPackages(self, __1: ListCheckOnlyPackagesRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListCheckOnlyPackagesResult]: ...  # type: ignore
    def ListDomainParametersChanges(self, __1: ListDomainParametersChangesRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListDomainParametersChangesResult]: ...  # type: ignore
    def ListAll(self, __1: ListAllRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListAllResponse]: ...  # type: ignore



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

if TYPE_CHECKING:
    from ..models.archived_event import ArchivedEvent


T = TypeVar("T", bound="EventType0")


@_attrs_define
class EventType0:
    """
    Attributes:
        archived_event (ArchivedEvent): Records that a contract has been archived, and choices may no longer be
            exercised on it.
    """

    archived_event: ArchivedEvent
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        archived_event = self.archived_event.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "ArchivedEvent": archived_event,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.archived_event import ArchivedEvent

        d = dict(src_dict)
        archived_event = ArchivedEvent.from_dict(d.pop("ArchivedEvent"))

        event_type_0 = cls(
            archived_event=archived_event,
        )

        event_type_0.additional_properties = d
        return event_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .command_submission_service_pb2 import SubmitReassignmentRequest, SubmitReassignmentResponse, SubmitRequest, SubmitResponse

__all__ = [
    "CommandSubmissionServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class CommandSubmissionServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _CommandSubmissionServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _CommandSubmissionServiceAsyncStub: ...  # type: ignore
    def Submit(self, __1: SubmitRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SubmitResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, SubmitResponse]: ...
    def SubmitReassignment(self, __1: SubmitReassignmentRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SubmitReassignmentResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, SubmitReassignmentResponse]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _CommandSubmissionServiceBlockingStub(CommandSubmissionServiceStub):
    def Submit(self, __1: SubmitRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SubmitResponse: ...
    def SubmitReassignment(self, __1: SubmitReassignmentRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SubmitReassignmentResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _CommandSubmissionServiceAsyncStub(CommandSubmissionServiceStub):
    def Submit(self, __1: SubmitRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SubmitResponse]: ...  # type: ignore
    def SubmitReassignment(self, __1: SubmitReassignmentRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SubmitReassignmentResponse]: ...  # type: ignore



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .pruning_service_pb2 import GetSafePruningOffsetRequest, GetSafePruningOffsetResponse, PruneRequest, PruneResponse
from ...pruning.v30.pruning_pb2 import ClearScheduleRequest, ClearScheduleResponse, GetNoWaitCommitmentsFromRequest, GetNoWaitCommitmentsFromResponse, GetParticipantScheduleRequest, GetParticipantScheduleResponse, GetScheduleRequest, GetScheduleResponse, ResetNoWaitCommitmentsFromRequest, ResetNoWaitCommitmentsFromResponse, SetCronRequest, SetCronResponse, SetMaxDurationRequest, SetMaxDurationResponse, SetNoWaitCommitmentsFromRequest, SetNoWaitCommitmentsFromResponse, SetParticipantScheduleRequest, SetParticipantScheduleResponse, SetRetentionRequest, SetRetentionResponse, SetScheduleRequest, SetScheduleResponse

__all__ = [
    "PruningServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class PruningServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _PruningServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _PruningServiceAsyncStub: ...  # type: ignore
    def Prune(self, __1: PruneRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> PruneResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, PruneResponse]: ...
    def GetSafePruningOffset(self, __1: GetSafePruningOffsetRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetSafePruningOffsetResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, GetSafePruningOffsetResponse]: ...
    def SetSchedule(self, __1: SetScheduleRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SetScheduleResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, SetScheduleResponse]: ...
    def SetParticipantSchedule(self, __1: SetParticipantScheduleRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SetParticipantScheduleResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, SetParticipantScheduleResponse]: ...
    def SetCron(self, __1: SetCronRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SetCronResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, SetCronResponse]: ...
    def SetMaxDuration(self, __1: SetMaxDurationRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SetMaxDurationResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, SetMaxDurationResponse]: ...
    def SetRetention(self, __1: SetRetentionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SetRetentionResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, SetRetentionResponse]: ...
    def ClearSchedule(self, __1: ClearScheduleRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ClearScheduleResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ClearScheduleResponse]: ...
    def GetSchedule(self, __1: GetScheduleRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetScheduleResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, GetScheduleResponse]: ...
    def GetParticipantSchedule(self, __1: GetParticipantScheduleRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetParticipantScheduleResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, GetParticipantScheduleResponse]: ...
    def SetNoWaitCommitmentsFrom(self, __1: SetNoWaitCommitmentsFromRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SetNoWaitCommitmentsFromResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, SetNoWaitCommitmentsFromResponse]: ...
    def ResetNoWaitCommitmentsFrom(self, __1: ResetNoWaitCommitmentsFromRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ResetNoWaitCommitmentsFromResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ResetNoWaitCommitmentsFromResponse]: ...
    def GetNoWaitCommitmentsFrom(self, __1: GetNoWaitCommitmentsFromRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetNoWaitCommitmentsFromResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, GetNoWaitCommitmentsFromResponse]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _PruningServiceBlockingStub(PruningServiceStub):
    def Prune(self, __1: PruneRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> PruneResponse: ...
    def GetSafePruningOffset(self, __1: GetSafePruningOffsetRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetSafePruningOffsetResponse: ...
    def SetSchedule(self, __1: SetScheduleRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SetScheduleResponse: ...
    def SetParticipantSchedule(self, __1: SetParticipantScheduleRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SetParticipantScheduleResponse: ...
    def SetCron(self, __1: SetCronRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SetCronResponse: ...
    def SetMaxDuration(self, __1: SetMaxDurationRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SetMaxDurationResponse: ...
    def SetRetention(self, __1: SetRetentionRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SetRetentionResponse: ...
    def ClearSchedule(self, __1: ClearScheduleRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ClearScheduleResponse: ...
    def GetSchedule(self, __1: GetScheduleRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetScheduleResponse: ...
    def GetParticipantSchedule(self, __1: GetParticipantScheduleRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetParticipantScheduleResponse: ...
    def SetNoWaitCommitmentsFrom(self, __1: SetNoWaitCommitmentsFromRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SetNoWaitCommitmentsFromResponse: ...
    def ResetNoWaitCommitmentsFrom(self, __1: ResetNoWaitCommitmentsFromRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ResetNoWaitCommitmentsFromResponse: ...
    def GetNoWaitCommitmentsFrom(self, __1: GetNoWaitCommitmentsFromRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetNoWaitCommitmentsFromResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _PruningServiceAsyncStub(PruningServiceStub):
    def Prune(self, __1: PruneRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, PruneResponse]: ...  # type: ignore
    def GetSafePruningOffset(self, __1: GetSafePruningOffsetRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetSafePruningOffsetResponse]: ...  # type: ignore
    def SetSchedule(self, __1: SetScheduleRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SetScheduleResponse]: ...  # type: ignore
    def SetParticipantSchedule(self, __1: SetParticipantScheduleRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SetParticipantScheduleResponse]: ...  # type: ignore
    def SetCron(self, __1: SetCronRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SetCronResponse]: ...  # type: ignore
    def SetMaxDuration(self, __1: SetMaxDurationRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SetMaxDurationResponse]: ...  # type: ignore
    def SetRetention(self, __1: SetRetentionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SetRetentionResponse]: ...  # type: ignore
    def ClearSchedule(self, __1: ClearScheduleRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ClearScheduleResponse]: ...  # type: ignore
    def GetSchedule(self, __1: GetScheduleRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetScheduleResponse]: ...  # type: ignore
    def GetParticipantSchedule(self, __1: GetParticipantScheduleRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetParticipantScheduleResponse]: ...  # type: ignore
    def SetNoWaitCommitmentsFrom(self, __1: SetNoWaitCommitmentsFromRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SetNoWaitCommitmentsFromResponse]: ...  # type: ignore
    def ResetNoWaitCommitmentsFrom(self, __1: ResetNoWaitCommitmentsFromRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ResetNoWaitCommitmentsFromResponse]: ...  # type: ignore
    def GetNoWaitCommitmentsFrom(self, __1: GetNoWaitCommitmentsFromRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetNoWaitCommitmentsFromResponse]: ...  # type: ignore



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/mediator/v30/mediator_status_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/admin/mediator/v30/mediator_status_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...health.v30 import status_service_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_health_dot_v30_dot_status__service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHcom/digitalasset/canton/admin/mediator/v30/mediator_status_service.proto\x12*com.digitalasset.canton.admin.mediator.v30\x1a=com/digitalasset/canton/admin/health/v30/status_service.proto\"\x17\n\x15MediatorStatusRequest\"\xdd\x03\n\x16MediatorStatusResponse\x12y\n\x06status\x18\x01 \x01(\x0b\x32_.com.digitalasset.canton.admin.mediator.v30.MediatorStatusResponse.MediatorStatusResponseStatusH\x00R\x06status\x12\x63\n\x0fnot_initialized\x18\x02 \x01(\x0b\x32\x38.com.digitalasset.canton.admin.health.v30.NotInitializedH\x00R\x0enotInitialized\x1a\xda\x01\n\x1cMediatorStatusResponseStatus\x12U\n\rcommon_status\x18\x01 \x01(\x0b\x32\x30.com.digitalasset.canton.admin.health.v30.StatusR\x0c\x63ommonStatus\x12\x38\n\x18physical_synchronizer_id\x18\x02 \x01(\tR\x16physicalSynchronizerId\x12)\n\x10protocol_version\x18\x03 \x01(\x05R\x0fprotocolVersionB\x06\n\x04kind2\xb1\x01\n\x15MediatorStatusService\x12\x97\x01\n\x0eMediatorStatus\x12\x41.com.digitalasset.canton.admin.mediator.v30.MediatorStatusRequest\x1a\x42.com.digitalasset.canton.admin.mediator.v30.MediatorStatusResponseB[ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/mediator/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.mediator.v30.mediator_status_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/mediator/v30'
  _globals['_MEDIATORSTATUSREQUEST']._serialized_start=183
  _globals['_MEDIATORSTATUSREQUEST']._serialized_end=206
  _globals['_MEDIATORSTATUSRESPONSE']._serialized_start=209
  _globals['_MEDIATORSTATUSRESPONSE']._serialized_end=686
  _globals['_MEDIATORSTATUSRESPONSE_MEDIATORSTATUSRESPONSESTATUS']._serialized_start=460
  _globals['_MEDIATORSTATUSRESPONSE_MEDIATORSTATUSRESPONSESTATUS']._serialized_end=678
  _globals['_MEDIATORSTATUSSERVICE']._serialized_start=689
  _globals['_MEDIATORSTATUSSERVICE']._serialized_end=866
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import object_meta_pb2 as _object_meta_pb2
from .. import crypto_pb2 as _crypto_pb2
from google.protobuf import field_mask_pb2 as _field_mask_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetParticipantIdRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetParticipantIdResponse(_message.Message):
    __slots__ = ("participant_id",)
    PARTICIPANT_ID_FIELD_NUMBER: _ClassVar[int]
    participant_id: str
    def __init__(self, participant_id: _Optional[str] = ...) -> None: ...

class GetPartiesRequest(_message.Message):
    __slots__ = ("parties", "identity_provider_id")
    PARTIES_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_PROVIDER_ID_FIELD_NUMBER: _ClassVar[int]
    parties: _containers.RepeatedScalarFieldContainer[str]
    identity_provider_id: str
    def __init__(self, parties: _Optional[_Iterable[str]] = ..., identity_provider_id: _Optional[str] = ...) -> None: ...

class GetPartiesResponse(_message.Message):
    __slots__ = ("party_details",)
    PARTY_DETAILS_FIELD_NUMBER: _ClassVar[int]
    party_details: _containers.RepeatedCompositeFieldContainer[PartyDetails]
    def __init__(self, party_details: _Optional[_Iterable[_Union[PartyDetails, _Mapping]]] = ...) -> None: ...

class ListKnownPartiesRequest(_message.Message):
    __slots__ = ("page_token", "page_size", "identity_provider_id", "filter_party")
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_PROVIDER_ID_FIELD_NUMBER: _ClassVar[int]
    FILTER_PARTY_FIELD_NUMBER: _ClassVar[int]
    page_token: str
    page_size: int
    identity_provider_id: str
    filter_party: str
    def __init__(self, page_token: _Optional[str] = ..., page_size: _Optional[int] = ..., identity_provider_id: _Optional[str] = ..., filter_party: _Optional[str] = ...) -> None: ...

class ListKnownPartiesResponse(_message.Message):
    __slots__ = ("party_details", "next_page_token")
    PARTY_DETAILS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    party_details: _containers.RepeatedCompositeFieldContainer[PartyDetails]
    next_page_token: str
    def __init__(self, party_details: _Optional[_Iterable[_Union[PartyDetails, _Mapping]]] = ..., next_page_token: _Optional[str] = ...) -> None: ...

class AllocatePartyRequest(_message.Message):
    __slots__ = ("party_id_hint", "local_metadata", "identity_provider_id", "synchronizer_id", "user_id")
    PARTY_ID_HINT_FIELD_NUMBER: _ClassVar[int]
    LOCAL_METADATA_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_PROVIDER_ID_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    party_id_hint: str
    local_metadata: _object_meta_pb2.ObjectMeta
    identity_provider_id: str
    synchronizer_id: str
    user_id: str
    def __init__(self, party_id_hint: _Optional[str] = ..., local_metadata: _Optional[_Union[_object_meta_pb2.ObjectMeta, _Mapping]] = ..., identity_provider_id: _Optional[str] = ..., synchronizer_id: _Optional[str] = ..., user_id: _Optional[str] = ...) -> None: ...

class AllocatePartyResponse(_message.Message):
    __slots__ = ("party_details",)
    PARTY_DETAILS_FIELD_NUMBER: _ClassVar[int]
    party_details: PartyDetails
    def __init__(self, party_details: _Optional[_Union[PartyDetails, _Mapping]] = ...) -> None: ...

class AllocateExternalPartyRequest(_message.Message):
    __slots__ = ("synchronizer", "onboarding_transactions", "multi_hash_signatures", "identity_provider_id")
    class SignedTransaction(_message.Message):
        __slots__ = ("transaction", "signatures")
        TRANSACTION_FIELD_NUMBER: _ClassVar[int]
        SIGNATURES_FIELD_NUMBER: _ClassVar[int]
        transaction: bytes
        signatures: _containers.RepeatedCompositeFieldContainer[_crypto_pb2.Signature]
        def __init__(self, transaction: _Optional[bytes] = ..., signatures: _Optional[_Iterable[_Union[_crypto_pb2.Signature, _Mapping]]] = ...) -> None: ...
    SYNCHRONIZER_FIELD_NUMBER: _ClassVar[int]
    ONBOARDING_TRANSACTIONS_FIELD_NUMBER: _ClassVar[int]
    MULTI_HASH_SIGNATURES_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_PROVIDER_ID_FIELD_NUMBER: _ClassVar[int]
    synchronizer: str
    onboarding_transactions: _containers.RepeatedCompositeFieldContainer[AllocateExternalPartyRequest.SignedTransaction]
    multi_hash_signatures: _containers.RepeatedCompositeFieldContainer[_crypto_pb2.Signature]
    identity_provider_id: str
    def __init__(self, synchronizer: _Optional[str] = ..., onboarding_transactions: _Optional[_Iterable[_Union[AllocateExternalPartyRequest.SignedTransaction, _Mapping]]] = ..., multi_hash_signatures: _Optional[_Iterable[_Union[_crypto_pb2.Signature, _Mapping]]] = ..., identity_provider_id: _Optional[str] = ...) -> None: ...

class AllocateExternalPartyResponse(_message.Message):
    __slots__ = ("party_id",)
    PARTY_ID_FIELD_NUMBER: _ClassVar[int]
    party_id: str
    def __init__(self, party_id: _Optional[str] = ...) -> None: ...

class UpdatePartyDetailsRequest(_message.Message):
    __slots__ = ("party_details", "update_mask")
    PARTY_DETAILS_FIELD_NUMBER: _ClassVar[int]
    UPDATE_MASK_FIELD_NUMBER: _ClassVar[int]
    party_details: PartyDetails
    update_mask: _field_mask_pb2.FieldMask
    def __init__(self, party_details: _Optional[_Union[PartyDetails, _Mapping]] = ..., update_mask: _Optional[_Union[_field_mask_pb2.FieldMask, _Mapping]] = ...) -> None: ...

class UpdatePartyDetailsResponse(_message.Message):
    __slots__ = ("party_details",)
    PARTY_DETAILS_FIELD_NUMBER: _ClassVar[int]
    party_details: PartyDetails
    def __init__(self, party_details: _Optional[_Union[PartyDetails, _Mapping]] = ...) -> None: ...

class PartyDetails(_message.Message):
    __slots__ = ("party", "is_local", "local_metadata", "identity_provider_id")
    PARTY_FIELD_NUMBER: _ClassVar[int]
    IS_LOCAL_FIELD_NUMBER: _ClassVar[int]
    LOCAL_METADATA_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_PROVIDER_ID_FIELD_NUMBER: _ClassVar[int]
    party: str
    is_local: bool
    local_metadata: _object_meta_pb2.ObjectMeta
    identity_provider_id: str
    def __init__(self, party: _Optional[str] = ..., is_local: bool = ..., local_metadata: _Optional[_Union[_object_meta_pb2.ObjectMeta, _Mapping]] = ..., identity_provider_id: _Optional[str] = ...) -> None: ...

class UpdatePartyIdentityProviderIdRequest(_message.Message):
    __slots__ = ("party", "source_identity_provider_id", "target_identity_provider_id")
    PARTY_FIELD_NUMBER: _ClassVar[int]
    SOURCE_IDENTITY_PROVIDER_ID_FIELD_NUMBER: _ClassVar[int]
    TARGET_IDENTITY_PROVIDER_ID_FIELD_NUMBER: _ClassVar[int]
    party: str
    source_identity_provider_id: str
    target_identity_provider_id: str
    def __init__(self, party: _Optional[str] = ..., source_identity_provider_id: _Optional[str] = ..., target_identity_provider_id: _Optional[str] = ...) -> None: ...

class UpdatePartyIdentityProviderIdResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GenerateExternalPartyTopologyRequest(_message.Message):
    __slots__ = ("synchronizer", "party_hint", "public_key", "local_participant_observation_only", "other_confirming_participant_uids", "confirmation_threshold", "observing_participant_uids")
    SYNCHRONIZER_FIELD_NUMBER: _ClassVar[int]
    PARTY_HINT_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    LOCAL_PARTICIPANT_OBSERVATION_ONLY_FIELD_NUMBER: _ClassVar[int]
    OTHER_CONFIRMING_PARTICIPANT_UIDS_FIELD_NUMBER: _ClassVar[int]
    CONFIRMATION_THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    OBSERVING_PARTICIPANT_UIDS_FIELD_NUMBER: _ClassVar[int]
    synchronizer: str
    party_hint: str
    public_key: _crypto_pb2.SigningPublicKey
    local_participant_observation_only: bool
    other_confirming_participant_uids: _containers.RepeatedScalarFieldContainer[str]
    confirmation_threshold: int
    observing_participant_uids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, synchronizer: _Optional[str] = ..., party_hint: _Optional[str] = ..., public_key: _Optional[_Union[_crypto_pb2.SigningPublicKey, _Mapping]] = ..., local_participant_observation_only: bool = ..., other_confirming_participant_uids: _Optional[_Iterable[str]] = ..., confirmation_threshold: _Optional[int] = ..., observing_participant_uids: _Optional[_Iterable[str]] = ...) -> None: ...

class GenerateExternalPartyTopologyResponse(_message.Message):
    __slots__ = ("party_id", "public_key_fingerprint", "topology_transactions", "multi_hash")
    PARTY_ID_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_KEY_FINGERPRINT_FIELD_NUMBER: _ClassVar[int]
    TOPOLOGY_TRANSACTIONS_FIELD_NUMBER: _ClassVar[int]
    MULTI_HASH_FIELD_NUMBER: _ClassVar[int]
    party_id: str
    public_key_fingerprint: str
    topology_transactions: _containers.RepeatedScalarFieldContainer[bytes]
    multi_hash: bytes
    def __init__(self, party_id: _Optional[str] = ..., public_key_fingerprint: _Optional[str] = ..., topology_transactions: _Optional[_Iterable[bytes]] = ..., multi_hash: _Optional[bytes] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class SetPassiveRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class SetPassiveResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/update_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/daml/ledger/api/v2/update_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import offset_checkpoint_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_offset__checkpoint__pb2
from . import reassignment_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_reassignment__pb2
from . import topology_transaction_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_topology__transaction__pb2
from . import transaction_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_transaction__pb2
from . import transaction_filter_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_transaction__filter__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+com/daml/ledger/api/v2/update_service.proto\x12\x16\x63om.daml.ledger.api.v2\x1a.com/daml/ledger/api/v2/offset_checkpoint.proto\x1a)com/daml/ledger/api/v2/reassignment.proto\x1a\x31\x63om/daml/ledger/api/v2/topology_transaction.proto\x1a(com/daml/ledger/api/v2/transaction.proto\x1a/com/daml/ledger/api/v2/transaction_filter.proto\"\xe0\x01\n\x11GetUpdatesRequest\x12\'\n\x0f\x62\x65gin_exclusive\x18\x01 \x01(\x03R\x0e\x62\x65ginExclusive\x12(\n\rend_inclusive\x18\x02 \x01(\x03H\x00R\x0c\x65ndInclusive\x88\x01\x01\x12I\n\rupdate_format\x18\x05 \x01(\x0b\x32$.com.daml.ledger.api.v2.UpdateFormatR\x0cupdateFormatB\x10\n\x0e_end_inclusiveJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05R\x06\x66ilterR\x07verbose\"\xee\x02\n\x12GetUpdatesResponse\x12G\n\x0btransaction\x18\x01 \x01(\x0b\x32#.com.daml.ledger.api.v2.TransactionH\x00R\x0btransaction\x12J\n\x0creassignment\x18\x02 \x01(\x0b\x32$.com.daml.ledger.api.v2.ReassignmentH\x00R\x0creassignment\x12W\n\x11offset_checkpoint\x18\x03 \x01(\x0b\x32(.com.daml.ledger.api.v2.OffsetCheckpointH\x00R\x10offsetCheckpoint\x12`\n\x14topology_transaction\x18\x04 \x01(\x0b\x32+.com.daml.ledger.api.v2.TopologyTransactionH\x00R\x13topologyTransactionB\x08\n\x06update\"}\n\x18GetUpdateByOffsetRequest\x12\x16\n\x06offset\x18\x01 \x01(\x03R\x06offset\x12I\n\rupdate_format\x18\x02 \x01(\x0b\x32$.com.daml.ledger.api.v2.UpdateFormatR\x0cupdateFormat\"~\n\x14GetUpdateByIdRequest\x12\x1b\n\tupdate_id\x18\x01 \x01(\tR\x08updateId\x12I\n\rupdate_format\x18\x02 \x01(\x0b\x32$.com.daml.ledger.api.v2.UpdateFormatR\x0cupdateFormat\"\x94\x02\n\x11GetUpdateResponse\x12G\n\x0btransaction\x18\x01 \x01(\x0b\x32#.com.daml.ledger.api.v2.TransactionH\x00R\x0btransaction\x12J\n\x0creassignment\x18\x02 \x01(\x0b\x32$.com.daml.ledger.api.v2.ReassignmentH\x00R\x0creassignment\x12`\n\x14topology_transaction\x18\x03 \x01(\x0b\x32+.com.daml.ledger.api.v2.TopologyTransactionH\x00R\x13topologyTransactionB\x08\n\x06update2\xd2\x02\n\rUpdateService\x12\x65\n\nGetUpdates\x12).com.daml.ledger.api.v2.GetUpdatesRequest\x1a*.com.daml.ledger.api.v2.GetUpdatesResponse0\x01\x12p\n\x11GetUpdateByOffset\x12\x30.com.daml.ledger.api.v2.GetUpdateByOffsetRequest\x1a).com.daml.ledger.api.v2.GetUpdateResponse\x12h\n\rGetUpdateById\x12,.com.daml.ledger.api.v2.GetUpdateByIdRequest\x1a).com.daml.ledger.api.v2.GetUpdateResponseB\x91\x01\n\x16\x63om.daml.ledger.api.v2B\x17UpdateServiceOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\xaa\x02\x16\x43om.Daml.Ledger.Api.V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.update_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.daml.ledger.api.v2B\027UpdateServiceOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\252\002\026Com.Daml.Ledger.Api.V2'
  _globals['_GETUPDATESREQUEST']._serialized_start=305
  _globals['_GETUPDATESREQUEST']._serialized_end=529
  _globals['_GETUPDATESRESPONSE']._serialized_start=532
  _globals['_GETUPDATESRESPONSE']._serialized_end=898
  _globals['_GETUPDATEBYOFFSETREQUEST']._serialized_start=900
  _globals['_GETUPDATEBYOFFSETREQUEST']._serialized_end=1025
  _globals['_GETUPDATEBYIDREQUEST']._serialized_start=1027
  _globals['_GETUPDATEBYIDREQUEST']._serialized_end=1153
  _globals['_GETUPDATERESPONSE']._serialized_start=1156
  _globals['_GETUPDATERESPONSE']._serialized_end=1432
  _globals['_UPDATESERVICE']._serialized_start=1435
  _globals['_UPDATESERVICE']._serialized_end=1773
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/synchronizer_connectivity.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/admin/participant/v30/synchronizer_connectivity.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...sequencer.v30 import sequencer_connection_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_sequencer_dot_v30_dot_sequencer__connection__pb2
from ...time.v30 import time_tracker_config_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_time_dot_v30_dot_time__tracker__config__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMcom/digitalasset/canton/admin/participant/v30/synchronizer_connectivity.proto\x12-com.digitalasset.canton.admin.participant.v30\x1a\x46\x63om/digitalasset/canton/admin/sequencer/v30/sequencer_connection.proto\x1a@com/digitalasset/canton/admin/time/v30/time_tracker_config.proto\x1a\x1egoogle/protobuf/duration.proto\"\x8b\x05\n\x1cSynchronizerConnectionConfig\x12-\n\x12synchronizer_alias\x18\x01 \x01(\tR\x11synchronizerAlias\x12v\n\x15sequencer_connections\x18\x02 \x01(\x0b\x32\x41.com.digitalasset.canton.admin.sequencer.v30.SequencerConnectionsR\x14sequencerConnections\x12%\n\x0emanual_connect\x18\x03 \x01(\x08R\rmanualConnect\x12\x38\n\x18physical_synchronizer_id\x18\x04 \x01(\tR\x16physicalSynchronizerId\x12\x1a\n\x08priority\x18\x05 \x01(\x05R\x08priority\x12I\n\x13initial_retry_delay\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationR\x11initialRetryDelay\x12\x41\n\x0fmax_retry_delay\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationR\rmaxRetryDelay\x12h\n\x0ctime_tracker\x18\x08 \x01(\x0b\x32\x45.com.digitalasset.canton.admin.time.v30.SynchronizerTimeTrackerConfigR\x0btimeTracker\x12O\n$initialize_from_trusted_synchronizer\x18\n \x01(\x08R!initializeFromTrustedSynchronizer\"H\n\x1dReconnectSynchronizersRequest\x12\'\n\x0fignore_failures\x18\x01 \x01(\x08R\x0eignoreFailures\" \n\x1eReconnectSynchronizersResponse\"\xc1\x04\n\x1bRegisterSynchronizerRequest\x12\x63\n\x06\x63onfig\x18\x01 \x01(\x0b\x32K.com.digitalasset.canton.admin.participant.v30.SynchronizerConnectionConfigR\x06\x63onfig\x12\x9a\x01\n\x17synchronizer_connection\x18\x02 \x01(\x0e\x32\x61.com.digitalasset.canton.admin.participant.v30.RegisterSynchronizerRequest.SynchronizerConnectionR\x16synchronizerConnection\x12\x92\x01\n\x1fsequencer_connection_validation\x18\x03 \x01(\x0e\x32J.com.digitalasset.canton.admin.sequencer.v30.SequencerConnectionValidationR\x1dsequencerConnectionValidation\"\x8a\x01\n\x16SynchronizerConnection\x12\'\n#SYNCHRONIZER_CONNECTION_UNSPECIFIED\x10\x00\x12 \n\x1cSYNCHRONIZER_CONNECTION_NONE\x10\x01\x12%\n!SYNCHRONIZER_CONNECTION_HANDSHAKE\x10\x02\"\x1e\n\x1cRegisterSynchronizerResponse\"\xf8\x02\n\x19ModifySynchronizerRequest\x12=\n\x18physical_synchronizer_id\x18\x01 \x01(\tH\x00R\x16physicalSynchronizerId\x88\x01\x01\x12j\n\nnew_config\x18\x02 \x01(\x0b\x32K.com.digitalasset.canton.admin.participant.v30.SynchronizerConnectionConfigR\tnewConfig\x12\x92\x01\n\x1fsequencer_connection_validation\x18\x03 \x01(\x0e\x32J.com.digitalasset.canton.admin.sequencer.v30.SequencerConnectionValidationR\x1dsequencerConnectionValidationB\x1b\n\x19_physical_synchronizer_id\"\x1c\n\x1aModifySynchronizerResponse\"$\n\"ListRegisteredSynchronizersRequest\"\x84\x03\n#ListRegisteredSynchronizersResponse\x12s\n\x07results\x18\x01 \x03(\x0b\x32Y.com.digitalasset.canton.admin.participant.v30.ListRegisteredSynchronizersResponse.ResultR\x07results\x1a\xe7\x01\n\x06Result\x12\x63\n\x06\x63onfig\x18\x01 \x01(\x0b\x32K.com.digitalasset.canton.admin.participant.v30.SynchronizerConnectionConfigR\x06\x63onfig\x12\x1c\n\tconnected\x18\x02 \x01(\x08R\tconnected\x12=\n\x18physical_synchronizer_id\x18\x03 \x01(\tH\x00R\x16physicalSynchronizerId\x88\x01\x01\x42\x1b\n\x19_physical_synchronizer_id\"c\n\x1cReconnectSynchronizerRequest\x12-\n\x12synchronizer_alias\x18\x01 \x01(\tR\x11synchronizerAlias\x12\x14\n\x05retry\x18\x02 \x01(\x08R\x05retry\"V\n\x1dReconnectSynchronizerResponse\x12\x35\n\x16\x63onnected_successfully\x18\x01 \x01(\x08R\x15\x63onnectedSuccessfully\"\x96\x02\n\x1a\x43onnectSynchronizerRequest\x12\x63\n\x06\x63onfig\x18\x01 \x01(\x0b\x32K.com.digitalasset.canton.admin.participant.v30.SynchronizerConnectionConfigR\x06\x63onfig\x12\x92\x01\n\x1fsequencer_connection_validation\x18\x02 \x01(\x0e\x32J.com.digitalasset.canton.admin.sequencer.v30.SequencerConnectionValidationR\x1dsequencerConnectionValidation\"T\n\x1b\x43onnectSynchronizerResponse\x12\x35\n\x16\x63onnected_successfully\x18\x01 \x01(\x08R\x15\x63onnectedSuccessfully\"N\n\x1d\x44isconnectSynchronizerRequest\x12-\n\x12synchronizer_alias\x18\x01 \x01(\tR\x11synchronizerAlias\" \n\x1e\x44isconnectSynchronizerResponse\"#\n!DisconnectAllSynchronizersRequest\"$\n\"DisconnectAllSynchronizersResponse\"#\n!ListConnectedSynchronizersRequest\"\xef\x02\n\"ListConnectedSynchronizersResponse\x12\x91\x01\n\x17\x63onnected_synchronizers\x18\x01 \x03(\x0b\x32X.com.digitalasset.canton.admin.participant.v30.ListConnectedSynchronizersResponse.ResultR\x16\x63onnectedSynchronizers\x1a\xb4\x01\n\x06Result\x12-\n\x12synchronizer_alias\x18\x01 \x01(\tR\x11synchronizerAlias\x12\'\n\x0fsynchronizer_id\x18\x02 \x01(\tR\x0esynchronizerId\x12\x38\n\x18physical_synchronizer_id\x18\x03 \x01(\tR\x16physicalSynchronizerId\x12\x18\n\x07healthy\x18\x04 \x01(\x08R\x07healthy\"I\n\x18GetSynchronizerIdRequest\x12-\n\x12synchronizer_alias\x18\x01 \x01(\tR\x11synchronizerAlias\"~\n\x19GetSynchronizerIdResponse\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12\x38\n\x18physical_synchronizer_id\x18\x02 \x01(\tR\x16physicalSynchronizerId\">\n\rLogoutRequest\x12-\n\x12synchronizer_alias\x18\x01 \x01(\tR\x11synchronizerAlias\"\x10\n\x0eLogoutResponse2\xd3\x0f\n\x1fSynchronizerConnectivityService\x12\xac\x01\n\x13\x43onnectSynchronizer\x12I.com.digitalasset.canton.admin.participant.v30.ConnectSynchronizerRequest\x1aJ.com.digitalasset.canton.admin.participant.v30.ConnectSynchronizerResponse\x12\xaf\x01\n\x14RegisterSynchronizer\x12J.com.digitalasset.canton.admin.participant.v30.RegisterSynchronizerRequest\x1aK.com.digitalasset.canton.admin.participant.v30.RegisterSynchronizerResponse\x12\xb5\x01\n\x16ReconnectSynchronizers\x12L.com.digitalasset.canton.admin.participant.v30.ReconnectSynchronizersRequest\x1aM.com.digitalasset.canton.admin.participant.v30.ReconnectSynchronizersResponse\x12\xb2\x01\n\x15ReconnectSynchronizer\x12K.com.digitalasset.canton.admin.participant.v30.ReconnectSynchronizerRequest\x1aL.com.digitalasset.canton.admin.participant.v30.ReconnectSynchronizerResponse\x12\xa9\x01\n\x12ModifySynchronizer\x12H.com.digitalasset.canton.admin.participant.v30.ModifySynchronizerRequest\x1aI.com.digitalasset.canton.admin.participant.v30.ModifySynchronizerResponse\x12\xb5\x01\n\x16\x44isconnectSynchronizer\x12L.com.digitalasset.canton.admin.participant.v30.DisconnectSynchronizerRequest\x1aM.com.digitalasset.canton.admin.participant.v30.DisconnectSynchronizerResponse\x12\xc1\x01\n\x1a\x44isconnectAllSynchronizers\x12P.com.digitalasset.canton.admin.participant.v30.DisconnectAllSynchronizersRequest\x1aQ.com.digitalasset.canton.admin.participant.v30.DisconnectAllSynchronizersResponse\x12\x85\x01\n\x06Logout\x12<.com.digitalasset.canton.admin.participant.v30.LogoutRequest\x1a=.com.digitalasset.canton.admin.participant.v30.LogoutResponse\x12\xc1\x01\n\x1aListConnectedSynchronizers\x12P.com.digitalasset.canton.admin.participant.v30.ListConnectedSynchronizersRequest\x1aQ.com.digitalasset.canton.admin.participant.v30.ListConnectedSynchronizersResponse\x12\xc4\x01\n\x1bListRegisteredSynchronizers\x12Q.com.digitalasset.canton.admin.participant.v30.ListRegisteredSynchronizersRequest\x1aR.com.digitalasset.canton.admin.participant.v30.ListRegisteredSynchronizersResponse\x12\xa6\x01\n\x11GetSynchronizerId\x12G.com.digitalasset.canton.admin.participant.v30.GetSynchronizerIdRequest\x1aH.com.digitalasset.canton.admin.participant.v30.GetSynchronizerIdResponseB^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.synchronizer_connectivity_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_SYNCHRONIZERCONNECTIONCONFIG']._serialized_start=299
  _globals['_SYNCHRONIZERCONNECTIONCONFIG']._serialized_end=950
  _globals['_RECONNECTSYNCHRONIZERSREQUEST']._serialized_start=952
  _globals['_RECONNECTSYNCHRONIZERSREQUEST']._serialized_end=1024
  _globals['_RECONNECTSYNCHRONIZERSRESPONSE']._serialized_start=1026
  _globals['_RECONNECTSYNCHRONIZERSRESPONSE']._serialized_end=1058
  _globals['_REGISTERSYNCHRONIZERREQUEST']._serialized_start=1061
  _globals['_REGISTERSYNCHRONIZERREQUEST']._serialized_end=1638
  _globals['_REGISTERSYNCHRONIZERREQUEST_SYNCHRONIZERCONNECTION']._serialized_start=1500
  _globals['_REGISTERSYNCHRONIZERREQUEST_SYNCHRONIZERCONNECTION']._serialized_end=1638
  _globals['_REGISTERSYNCHRONIZERRESPONSE']._serialized_start=1640
  _globals['_REGISTERSYNCHRONIZERRESPONSE']._serialized_end=1670
  _globals['_MODIFYSYNCHRONIZERREQUEST']._serialized_start=1673
  _globals['_MODIFYSYNCHRONIZERREQUEST']._serialized_end=2049
  _globals['_MODIFYSYNCHRONIZERRESPONSE']._serialized_start=2051
  _globals['_MODIFYSYNCHRONIZERRESPONSE']._serialized_end=2079
  _globals['_LISTREGISTEREDSYNCHRONIZERSREQUEST']._serialized_start=2081
  _globals['_LISTREGISTEREDSYNCHRONIZERSREQUEST']._serialized_end=2117
  _globals['_LISTREGISTEREDSYNCHRONIZERSRESPONSE']._serialized_start=2120
  _globals['_LISTREGISTEREDSYNCHRONIZERSRESPONSE']._serialized_end=2508
  _globals['_LISTREGISTEREDSYNCHRONIZERSRESPONSE_RESULT']._serialized_start=2277
  _globals['_LISTREGISTEREDSYNCHRONIZERSRESPONSE_RESULT']._serialized_end=2508
  _globals['_RECONNECTSYNCHRONIZERREQUEST']._serialized_start=2510
  _globals['_RECONNECTSYNCHRONIZERREQUEST']._serialized_end=2609
  _globals['_RECONNECTSYNCHRONIZERRESPONSE']._serialized_start=2611
  _globals['_RECONNECTSYNCHRONIZERRESPONSE']._serialized_end=2697
  _globals['_CONNECTSYNCHRONIZERREQUEST']._serialized_start=2700
  _globals['_CONNECTSYNCHRONIZERREQUEST']._serialized_end=2978
  _globals['_CONNECTSYNCHRONIZERRESPONSE']._serialized_start=2980
  _globals['_CONNECTSYNCHRONIZERRESPONSE']._serialized_end=3064
  _globals['_DISCONNECTSYNCHRONIZERREQUEST']._serialized_start=3066
  _globals['_DISCONNECTSYNCHRONIZERREQUEST']._serialized_end=3144
  _globals['_DISCONNECTSYNCHRONIZERRESPONSE']._serialized_start=3146
  _globals['_DISCONNECTSYNCHRONIZERRESPONSE']._serialized_end=3178
  _globals['_DISCONNECTALLSYNCHRONIZERSREQUEST']._serialized_start=3180
  _globals['_DISCONNECTALLSYNCHRONIZERSREQUEST']._serialized_end=3215
  _globals['_DISCONNECTALLSYNCHRONIZERSRESPONSE']._serialized_start=3217
  _globals['_DISCONNECTALLSYNCHRONIZERSRESPONSE']._serialized_end=3253
  _globals['_LISTCONNECTEDSYNCHRONIZERSREQUEST']._serialized_start=3255
  _globals['_LISTCONNECTEDSYNCHRONIZERSREQUEST']._serialized_end=3290
  _globals['_LISTCONNECTEDSYNCHRONIZERSRESPONSE']._serialized_start=3293
  _globals['_LISTCONNECTEDSYNCHRONIZERSRESPONSE']._serialized_end=3660
  _globals['_LISTCONNECTEDSYNCHRONIZERSRESPONSE_RESULT']._serialized_start=3480
  _globals['_LISTCONNECTEDSYNCHRONIZERSRESPONSE_RESULT']._serialized_end=3660
  _globals['_GETSYNCHRONIZERIDREQUEST']._serialized_start=3662
  _globals['_GETSYNCHRONIZERIDREQUEST']._serialized_end=3735
  _globals['_GETSYNCHRONIZERIDRESPONSE']._serialized_start=3737
  _globals['_GETSYNCHRONIZERIDRESPONSE']._serialized_end=3863
  _globals['_LOGOUTREQUEST']._serialized_start=3865
  _globals['_LOGOUTREQUEST']._serialized_end=3927
  _globals['_LOGOUTRESPONSE']._serialized_start=3929
  _globals['_LOGOUTRESPONSE']._serialized_end=3945
  _globals['_SYNCHRONIZERCONNECTIVITYSERVICE']._serialized_start=3948
  _globals['_SYNCHRONIZERCONNECTIVITYSERVICE']._serialized_end=5951
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.js_reassignment_event_type_0 import JsReassignmentEventType0
    from ..models.js_reassignment_event_type_1 import JsReassignmentEventType1
    from ..models.trace_context import TraceContext


T = TypeVar("T", bound="JsReassignment")


@_attrs_define
class JsReassignment:
    """Complete view of an on-ledger reassignment.

    Attributes:
        update_id (str): Assigned by the server. Useful for correlating logs.
            Must be a valid LedgerString (as described in ``value.proto``).
            Required
        command_id (str): The ID of the command which resulted in this reassignment. Missing for everyone except the
            submitting party on the submitting participant.
            Must be a valid LedgerString (as described in ``value.proto``).
            Optional
        workflow_id (str): The workflow ID used in reassignment command submission. Only set if the ``workflow_id`` for
            the command was set.
            Must be a valid LedgerString (as described in ``value.proto``).
            Optional
        offset (int): The participant's offset. The details of this field are described in ``community/ledger-
            api/README.md``.
            Required, must be a valid absolute offset (positive integer).
        record_time (str): The time at which the reassignment was recorded. The record time refers to the source/target
            synchronizer for an unassign/assign event respectively.
            Required
        synchronizer_id (str): A valid synchronizer id.
            Identifies the synchronizer that synchronized this Reassignment.
            Required
        events (list[JsReassignmentEventType0 | JsReassignmentEventType1] | Unset): The collection of reassignment
            events. Required.
        trace_context (TraceContext | Unset):
    """

    update_id: str
    command_id: str
    workflow_id: str
    offset: int
    record_time: str
    synchronizer_id: str
    events: list[JsReassignmentEventType0 | JsReassignmentEventType1] | Unset = UNSET
    trace_context: TraceContext | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        from ..models.js_reassignment_event_type_0 import JsReassignmentEventType0

        update_id = self.update_id

        command_id = self.command_id

        workflow_id = self.workflow_id

        offset = self.offset

        record_time = self.record_time

        synchronizer_id = self.synchronizer_id

        events: list[dict[str, Any]] | Unset = UNSET
        if not isinstance(self.events, Unset):
            events = []
            for events_item_data in self.events:
                events_item: dict[str, Any]
                if isinstance(events_item_data, JsReassignmentEventType0):
                    events_item = events_item_data.to_dict()
                else:
                    events_item = events_item_data.to_dict()

                events.append(events_item)

        trace_context: dict[str, Any] | Unset = UNSET
        if not isinstance(self.trace_context, Unset):
            trace_context = self.trace_context.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "updateId": update_id,
                "commandId": command_id,
                "workflowId": workflow_id,
                "offset": offset,
                "recordTime": record_time,
                "synchronizerId": synchronizer_id,
            }
        )
        if events is not UNSET:
            field_dict["events"] = events
        if trace_context is not UNSET:
            field_dict["traceContext"] = trace_context

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.js_reassignment_event_type_0 import JsReassignmentEventType0
        from ..models.js_reassignment_event_type_1 import JsReassignmentEventType1
        from ..models.trace_context import TraceContext

        d = dict(src_dict)
        update_id = d.pop("updateId")

        command_id = d.pop("commandId")

        workflow_id = d.pop("workflowId")

        offset = d.pop("offset")

        record_time = d.pop("recordTime")

        synchronizer_id = d.pop("synchronizerId")

        _events = d.pop("events", UNSET)
        events: list[JsReassignmentEventType0 | JsReassignmentEventType1] | Unset = (
            UNSET
        )
        if _events is not UNSET:
            events = []
            for events_item_data in _events:

                def _parse_events_item(
                    data: object,
                ) -> JsReassignmentEventType0 | JsReassignmentEventType1:
                    try:
                        if not isinstance(data, dict):
                            raise TypeError()
                        componentsschemas_js_reassignment_event_type_0 = (
                            JsReassignmentEventType0.from_dict(data)
                        )

                        return componentsschemas_js_reassignment_event_type_0
                    except (TypeError, ValueError, AttributeError, KeyError):
                        pass
                    if not isinstance(data, dict):
                        raise TypeError()
                    componentsschemas_js_reassignment_event_type_1 = (
                        JsReassignmentEventType1.from_dict(data)
                    )

                    return componentsschemas_js_reassignment_event_type_1

                events_item = _parse_events_item(events_item_data)

                events.append(events_item)

        _trace_context = d.pop("traceContext", UNSET)
        trace_context: TraceContext | Unset
        if isinstance(_trace_context, Unset):
            trace_context = UNSET
        else:
            trace_context = TraceContext.from_dict(_trace_context)

        js_reassignment = cls(
            update_id=update_id,
            command_id=command_id,
            workflow_id=workflow_id,
            offset=offset,
            record_time=record_time,
            synchronizer_id=synchronizer_id,
            events=events,
            trace_context=trace_context,
        )

        js_reassignment.additional_properties = d
        return js_reassignment

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ....health.admin.v0 import status_service_pb2 as _status_service_pb2
from ....health.admin.v1 import status_service_pb2 as _status_service_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MediatorStatusRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MediatorStatusResponse(_message.Message):
    __slots__ = ("status", "unavailable", "failure")
    class MediatorStatusResponseStatus(_message.Message):
        __slots__ = ("common_status", "domain_id", "protocol_version")
        COMMON_STATUS_FIELD_NUMBER: _ClassVar[int]
        DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
        PROTOCOL_VERSION_FIELD_NUMBER: _ClassVar[int]
        common_status: _status_service_pb2_1.Status
        domain_id: str
        protocol_version: int
        def __init__(self, common_status: _Optional[_Union[_status_service_pb2_1.Status, _Mapping]] = ..., domain_id: _Optional[str] = ..., protocol_version: _Optional[int] = ...) -> None: ...
    STATUS_FIELD_NUMBER: _ClassVar[int]
    UNAVAILABLE_FIELD_NUMBER: _ClassVar[int]
    FAILURE_FIELD_NUMBER: _ClassVar[int]
    status: MediatorStatusResponse.MediatorStatusResponseStatus
    unavailable: _status_service_pb2.NodeStatus.NotInitialized
    failure: _status_service_pb2_1.Failure
    def __init__(self, status: _Optional[_Union[MediatorStatusResponse.MediatorStatusResponseStatus, _Mapping]] = ..., unavailable: _Optional[_Union[_status_service_pb2.NodeStatus.NotInitialized, _Mapping]] = ..., failure: _Optional[_Union[_status_service_pb2_1.Failure, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from enum import Enum


class ConnectedSynchronizerPermission(str, Enum):
    PARTICIPANT_PERMISSION_CONFIRMATION = "PARTICIPANT_PERMISSION_CONFIRMATION"
    PARTICIPANT_PERMISSION_OBSERVATION = "PARTICIPANT_PERMISSION_OBSERVATION"
    PARTICIPANT_PERMISSION_SUBMISSION = "PARTICIPANT_PERMISSION_SUBMISSION"
    PARTICIPANT_PERMISSION_UNSPECIFIED = "PARTICIPANT_PERMISSION_UNSPECIFIED"

    def __str__(self) -> str:
        return str(self.value)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="ExerciseCommand")


@_attrs_define
class ExerciseCommand:
    """Exercise a choice on an existing contract.

    Attributes:
        template_id (str): The template or interface of the contract the client wants to exercise.
            Both package-name and package-id reference identifier formats for the template-id are supported.
            Note: The package-id reference identifier format is deprecated. We plan to end support for this format in
            version 3.4.
            To exercise a choice on an interface, specify the interface identifier in the template_id field.

            Required
        contract_id (str): The ID of the contract the client wants to exercise upon.
            Must be a valid LedgerString (as described in ``value.proto``).
            Required
        choice (str): The name of the choice the client wants to exercise.
            Must be a valid NameString (as described in ``value.proto``)
            Required
        choice_argument (Any): The argument for this choice.
            Required
    """

    template_id: str
    contract_id: str
    choice: str
    choice_argument: Any
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        template_id = self.template_id

        contract_id = self.contract_id

        choice = self.choice

        choice_argument = self.choice_argument

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "templateId": template_id,
                "contractId": contract_id,
                "choice": choice,
                "choiceArgument": choice_argument,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        template_id = d.pop("templateId")

        contract_id = d.pop("contractId")

        choice = d.pop("choice")

        choice_argument = d.pop("choiceArgument")

        exercise_command = cls(
            template_id=template_id,
            contract_id=contract_id,
            choice=choice,
            choice_argument=choice_argument,
        )

        exercise_command.additional_properties = d
        return exercise_command

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .sequencer_connect_service_pb2 import SequencerConnect
from .sequencer_connect_service_pb2_grpc import SequencerConnectServiceStub
from .sequencer_authentication_service_pb2 import SequencerAuthentication
from .sequencer_authentication_service_pb2_grpc import SequencerAuthenticationServiceStub
from .sequencer_service_pb2 import AcknowledgeRequest, AcknowledgeResponse, AcknowledgeSignedRequest, AcknowledgeSignedResponse, DownloadTopologyStateForInitHashRequest, DownloadTopologyStateForInitHashResponse, DownloadTopologyStateForInitRequest, DownloadTopologyStateForInitResponse, GetTimeRequest, GetTimeResponse, GetTrafficStateForMemberRequest, GetTrafficStateForMemberResponse, SendAsyncRequest, SendAsyncResponse, SubscriptionRequest, SubscriptionResponse, TrafficControlErrorReason
from .sequencer_service_pb2_grpc import SequencerServiceStub
from .sequencer_channel_service_pb2 import ConnectToSequencerChannelRequest, ConnectToSequencerChannelResponse, PingRequest, PingResponse, SequencerChannelConnectedToAllEndpoints, SequencerChannelMetadata, SequencerChannelSessionKey, SequencerChannelSessionKeyAck
from .sequencer_channel_service_pb2_grpc import SequencerChannelServiceStub

__all__ = [
    "AcknowledgeRequest",
    "AcknowledgeResponse",
    "AcknowledgeSignedRequest",
    "AcknowledgeSignedResponse",
    "ConnectToSequencerChannelRequest",
    "ConnectToSequencerChannelResponse",
    "DownloadTopologyStateForInitHashRequest",
    "DownloadTopologyStateForInitHashResponse",
    "DownloadTopologyStateForInitRequest",
    "DownloadTopologyStateForInitResponse",
    "GetTimeRequest",
    "GetTimeResponse",
    "GetTrafficStateForMemberRequest",
    "GetTrafficStateForMemberResponse",
    "PingRequest",
    "PingResponse",
    "SendAsyncRequest",
    "SendAsyncResponse",
    "SequencerAuthentication",
    "SequencerAuthenticationServiceStub",
    "SequencerChannelConnectedToAllEndpoints",
    "SequencerChannelMetadata",
    "SequencerChannelServiceStub",
    "SequencerChannelSessionKey",
    "SequencerChannelSessionKeyAck",
    "SequencerConnect",
    "SequencerConnectServiceStub",
    "SequencerServiceStub",
    "SubscriptionRequest",
    "SubscriptionResponse",
    "TrafficControlErrorReason",
]
